==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/da_dk/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.options_updated'] = 'Indstillingerne for systemoversigten blev opdateret!';
$lang['AdminMain.index.boxtitle_overview'] = 'Systemoversigt';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktive kunder';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktive tjenester';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Tjenester, der er planlagt til aflysning';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Brugere aktive i dag';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Tilbagevendende fakturaer';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Afventende ordrer';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Åbne billetter';
$lang['AdminMain.overview.heading_users'] = 'Seneste brugere';
$lang['AdminMain.overview.tab_all'] = 'Grafer';
$lang['AdminMain.overview.tab_clients'] = 'Kunder';
$lang['AdminMain.overview.tab_services'] = 'Tjenester';
$lang['AdminMain.overview.tooltip_activity'] = 'Sidste aktivitet';
$lang['AdminMain.overview.tooltip_location'] = 'Placering';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Lige nu';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minut siden';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minutter siden';
$lang['AdminMain.date_range.days'] = '%1$s Dage';
$lang['AdminMain.settings.heading_statistics'] = 'Statistik';
$lang['AdminMain.settings.text_options'] = 'Kontrollér de indstillinger, der vises på systemoversigten.';
$lang['AdminMain.settings.clients_active'] = 'Aktive kunder';
$lang['AdminMain.settings.services_active'] = 'Aktive tjenester';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Tjenester, der er planlagt til aflysning';
$lang['AdminMain.settings.active_users_today'] = 'Brugere aktive i dag';
$lang['AdminMain.settings.recurring_invoices'] = 'Tilbagevendende fakturaer';
$lang['AdminMain.settings.open_tickets'] = 'Åbne billetter';
$lang['AdminMain.settings.pending_orders'] = 'Afventende ordrer';
$lang['AdminMain.settings.heading_clients'] = 'Fanen Kunder';
$lang['AdminMain.settings.text_graphs_clients'] = 'Kontroller, hvilke grafer der skal vises på fanen Klienter.';
$lang['AdminMain.settings.graph_clients'] = 'Graf over kunder';
$lang['AdminMain.settings.heading_services'] = 'Fanen Tjenester';
$lang['AdminMain.settings.text_graphs_services'] = 'Kontroller, hvilke grafer der skal vises på fanen Tjenester.';
$lang['AdminMain.settings.graph_services'] = 'Graf over tjenester';
$lang['AdminMain.settings.heading_settings'] = 'Indstillinger';
$lang['AdminMain.settings.show_one_tab'] = 'Vis kun én fane';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Adskiller ikke længere grafer i faner, men viser dem i stedet alle i en enkelt fane.';
$lang['AdminMain.settings.show_legend'] = 'Vis legende';
$lang['AdminMain.settings.date_range'] = 'Grafisk datointerval';
$lang['AdminMain.settings.submit_cancel'] = 'Tilbage til oversigt';
$lang['AdminMain.settings.submit_settings'] = 'Opdater indstillinger';
$lang['AdminMain.graph_name.graph_services'] = 'Tjenester';
$lang['AdminMain.graph_name.graph_clients'] = 'Kunder';
$lang['AdminMain.graph_line_name.active'] = 'Aktiv';
$lang['AdminMain.graph_line_name.canceled'] = 'Aflyst';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspenderet';
$lang['AdminMain.graph_line_name.new'] = 'Ny';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/da_dk/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.options_updated'] = 'Indstillingerne for systemoversigten blev opdateret!';
$lang['AdminMain.index.boxtitle_overview'] = 'Systemoversigt';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktive kunder';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktive tjenester';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Tjenester, der er planlagt til aflysning';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Brugere aktive i dag';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Tilbagevendende fakturaer';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Afventende ordrer';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Åbne billetter';
$lang['AdminMain.overview.heading_users'] = 'Seneste brugere';
$lang['AdminMain.overview.tab_all'] = 'Grafer';
$lang['AdminMain.overview.tab_clients'] = 'Kunder';
$lang['AdminMain.overview.tab_services'] = 'Tjenester';
$lang['AdminMain.overview.tooltip_activity'] = 'Sidste aktivitet';
$lang['AdminMain.overview.tooltip_location'] = 'Placering';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Lige nu';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minut siden';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minutter siden';
$lang['AdminMain.date_range.days'] = '%1$s Dage';
$lang['AdminMain.settings.heading_statistics'] = 'Statistik';
$lang['AdminMain.settings.text_options'] = 'Kontrollér de indstillinger, der vises på systemoversigten.';
$lang['AdminMain.settings.clients_active'] = 'Aktive kunder';
$lang['AdminMain.settings.services_active'] = 'Aktive tjenester';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Tjenester, der er planlagt til aflysning';
$lang['AdminMain.settings.active_users_today'] = 'Brugere aktive i dag';
$lang['AdminMain.settings.recurring_invoices'] = 'Tilbagevendende fakturaer';
$lang['AdminMain.settings.open_tickets'] = 'Åbne billetter';
$lang['AdminMain.settings.pending_orders'] = 'Afventende ordrer';
$lang['AdminMain.settings.heading_clients'] = 'Fanen Kunder';
$lang['AdminMain.settings.text_graphs_clients'] = 'Kontroller, hvilke grafer der skal vises på fanen Klienter.';
$lang['AdminMain.settings.graph_clients'] = 'Graf over kunder';
$lang['AdminMain.settings.heading_services'] = 'Fanen Tjenester';
$lang['AdminMain.settings.text_graphs_services'] = 'Kontroller, hvilke grafer der skal vises på fanen Tjenester.';
$lang['AdminMain.settings.graph_services'] = 'Graf over tjenester';
$lang['AdminMain.settings.heading_settings'] = 'Indstillinger';
$lang['AdminMain.settings.show_one_tab'] = 'Vis kun én fane';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Adskiller ikke længere grafer i faner, men viser dem i stedet alle i en enkelt fane.';
$lang['AdminMain.settings.show_legend'] = 'Vis legende';
$lang['AdminMain.settings.date_range'] = 'Grafisk datointerval';
$lang['AdminMain.settings.submit_cancel'] = 'Tilbage til oversigt';
$lang['AdminMain.settings.submit_settings'] = 'Opdater indstillinger';
$lang['AdminMain.graph_name.graph_services'] = 'Tjenester';
$lang['AdminMain.graph_name.graph_clients'] = 'Kunder';
$lang['AdminMain.graph_line_name.active'] = 'Aktiv';
$lang['AdminMain.graph_line_name.canceled'] = 'Aflyst';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspenderet';
$lang['AdminMain.graph_line_name.new'] = 'Ny';
$lang['AdminMain.date_range.day'] = '1 dag';
$lang['AdminMain.date_range.month'] = 'Nuværende måned';
$lang['AdminMain.date_range.ytd'] = 'År til dato';
